# nodejs8-oracledb.spec
#
# Builds the node-oracledb driver for Node.js 8
#
# A zip file downloaded from the node-oracledb github tag should be in
# SOURCES/node-oracledb-x.y.z.zip

# The version of node-oracledb extension being installed
%define nodeoracledbver 4.0.0

# The Node.js version
%define nodejsmainver 8
%define nextnodejsver 9
%define nodejspatchver 1.0
%define nodejsver %{nodejsmainver}.%{nodejspatchver}

# add odpi as a seperate package.
%define odpiver 3.2.0

# Instant Client version
%define ocimainver 18.3
%define ocipatchver 0.0.0
%define ociver %{ocimainver}.%{ocipatchver}

# Can't use %{_libdir} since it is /usr/lib64
%define mylibdir /usr/lib

# Needed for 'npm install'
%define httpproxy http://www-proxy.us.oracle.com:80/

# Test DB connection string and SYSTEM password
%define connectstring  localhost/orcl
%define systempw oracle

Summary: The node-oracledb add-on allows Node.js applications to connect to Oracle Database
Name: node-oracledb-node%{nodejsmainver}
Group: Development/Languages
Version: %{nodeoracledbver}
Release: 1%{?dist}
License: Apache 2.0
URL: https://github.com/oracle/node-oracledb/

# This is the GitHub URL to pull from:
#   https://github.com/oracle/node-oracledb/archive/v%{nodeoracledbver}.zip
# The file name that is downloaded from that GitHub URL needs to be used:
Source0: node-oracledb-%{nodeoracledbver}.zip
Source1: createtestuser.sql
Source2: droptestuser.sql
Source3: odpi-%{odpiver}.zip

BuildRequires: nodejs >= %{nodejsmainver}, nodejs < %{nextnodejsver}
BuildRequires: oracle-instantclient18.3-basic >= %{ociver}
BuildRequires: oracle-instantclient18.3-devel >= %{ociver}
BuildRequires: oracle-instantclient18.3-sqlplus >= %{ociver}
BuildRequires: devtoolset-3

Requires: nodejs >= %{nodejsmainver}, nodejs < %{nextnodejsver}
Requires: oracle-instantclient18.3-basic >= %{ociver}

# Stop install of the generated RPM failing with the error: "Requires: libclntsh.so.12.1()(64bit)"
AutoReqProv: no

Provides: nodejs-oracledb = %{version}-%{release}

Obsoletes: node-oracledb-12c-node%{nodejsmainver}

%description
The node-oracledb add-on for Node.js powers high performance Oracle Database applications.

%prep
%setup -q -c -n node-oracledb-%{version}
rm -rf %{_builddir}/odpi-%{odpiver}
%setup -T -D -a 3 -q -c -n odpi-%{odpiver}
mv -f %{_builddir}/odpi-%{odpiver}/odpi*/* %{_builddir}/node-oracledb-%{version}/node-oracledb-%{version}/odpi/

rm -rf %{_builddir}/node_modules
mkdir %{_builddir}/node_modules
npm cache verify

%build
cd %{_builddir}

export http_proxy=%{httpproxy}
export https_proxy=%{httpproxy}

# Workaround PATH getting reset by npm
export CXX=/opt/rh/devtoolset-3/root/usr/bin/g++

npm install nan
cd node-oracledb-%{nodeoracledbver}/node-oracledb-%{nodeoracledbver}
scl enable devtoolset-3 -- npm install
cd ../..
mv node-oracledb-%{nodeoracledbver}/node-oracledb-%{nodeoracledbver} node_modules/oracledb
unset CXX

%check

# Note this tests the install in the build dir, not the buildroot. The latter is packaged up.
runtests() {

    cd %{_builddir}/node-oracledb-%{nodeoracledbver}

    export PATH=/usr/lib/oracle/%{ocimainver}/client64/bin:$PATH
    export LD_LIBRARY_PATH=/usr/lib/oracle/%{ocimainver}/client64/lib:$LD_LIBRARY_PATH
    export http_proxy=%{httpproxy}
    export https_proxy=%{httpproxy}

    npm install mocha should async

    # Create a temporary DB user and run the tests
    export NODE_ORACLEDB_USER='nodetest'$$
    export NODE_ORACLEDB_PASSWORD=$NODE_ORACLEDB_USER
    export NODE_ORACLEDB_CONNECTIONSTRING=%{connectstring}
    sqlplus  -l system/%{systempw}@$NODE_ORACLEDB_CONNECTIONSTRING @%{_sourcedir}/createtestuser.sql $NODE_ORACLEDB_USER $NODE_ORACLEDB_PASSWORD
    cd %{_builddir}/node_modules/oracledb
    npm test
    sqlplus -l system/%{systempw}@$NODE_ORACLEDB_CONNECTIONSTRING @%{_sourcedir}/droptestuser.sql $NODE_ORACLEDB_USER

}

# Comment out the following 'runtests' line to skip testing
#runtests

%install
[ "$RPM_BUILD_ROOT" != "/" ] && rm -rf $RPM_BUILD_ROOT

mkdir -p $RPM_BUILD_ROOT

install -m 755 -d $RPM_BUILD_ROOT%{mylibdir}/node_modules/oracledb/build/Release
install -m 755 %{_builddir}/node_modules/oracledb/build/Release/oracledb.node $RPM_BUILD_ROOT%{mylibdir}/node_modules/oracledb/build/Release
install -m 755 -d $RPM_BUILD_ROOT%{mylibdir}/node_modules/oracledb/lib
install -m 644 %{_builddir}/node_modules/oracledb/lib/*.js $RPM_BUILD_ROOT%{mylibdir}/node_modules/oracledb/lib/
install -m 644 %{_builddir}/node_modules/oracledb/index.js $RPM_BUILD_ROOT%{mylibdir}/node_modules/oracledb
install -m 644 %{_builddir}/node_modules/oracledb/LICENSE.md $RPM_BUILD_ROOT%{mylibdir}/node_modules/oracledb
install -m 644 %{_builddir}/node_modules/oracledb/README.md $RPM_BUILD_ROOT%{mylibdir}/node_modules/oracledb
install -m 644 %{_builddir}/node_modules/oracledb/package.json $RPM_BUILD_ROOT%{mylibdir}/node_modules/oracledb

%clean
[ "$RPM_BUILD_ROOT" != "/" ] && rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root)
%{mylibdir}/node_modules/oracledb/*

%changelog
* Wed Jul 24 2019 EL Errata <el-errata_ww@oracle.com> 4.0.0-1
- Update node-oracledb to 4.0.0 and odpi to 3.2.0

* Thu Feb 21 2019 EL Errata <el-errata_ww@oracle.com> 3.1.2-1
- Update node-oracledb to 3.1.2 and odpi to 3.1.2

* Thu Jan 24 2019 EL Errata <el-errata_ww@oracle.com> 3.1.1-1
- Update to version 3.1.1

* Tue Jan 22 2019 EL Errata <el-errata_ww@oracle.com> 3.1.0-1
- Update node-oracledb to 3.1.0 and odpi to 3.1.0

* Wed Dec 05 2018 EL Errata <el-errata_ww@oracle.com> 3.0.1-1
- Update to version 3.0.1

* Tue Oct 02 2018 John Mcwalters <john.mcwalters@oracle.com> 3.0.0-1
- Update node-oracledb to 3.0.0 and odpi to 3.0.0
- Use instantclient version 18.3

* Fri Jun 08 2018 Srinivas Maturi <srinivas.maturi@oracle.com> - 2.3.0
- upgrade to version 2.3.0, odpi to 2.4.0

* Tue Apr 3 2018 Qing Lin          <qing.lin@oracle.com>          - 2.2.0
    - upgrade to version 2.2.0, odpi to 2.3.0

* Wed Mar 07 2018 Qing Lin          <qing.lin@oracle.com>          - 2.1.2
    - upgrade to version 2.1.2.

* Tue Feb 20 2018 Qing Lin          <qing.lin@oracle.com>          - 2.1.1
    - upgrade to version 2.1.1.

* Tue Dec  19 2017 Qing Lin          <qing.lin@oracle.com>
    - upgrade to 2.0.15
    - add odpi as a seperate source package.

* Mon Dec  18 2017 Keshav Sharma <keshav.sharma@oracle.com> 1.13.1-1
    - Updated to 1.13.1 
* Mon Jan 30 2017 P. Venkatraman    <p.venkatraman@oracle.com>     - 1.12.2
* Fri Nov  4 2016 Christopher Jones <christopher.jones@oracle.com> - Created
